import * as poly2tri from 'poly2tri';
import type { Point, Ring, Triangle, UniquePointsIndexTriangle } from '@allmaps/types';
/**
 * Triangle object from [poly2tri](https://github.com/r3mi/poly2tri.js/) package
 * @typedef {Object} poly2tri.Triangle
 */
/**
 * Triangulates a polygon (and returns the full Poly2tri output)
 *
 * @remark Use this function to access the rich poly2tri triangulation output (information on constrained edges, neighbours, interior).
 *
 * @param {Ring} polygon - Polygon
 * @param {number} distance - Distance between the Steiner points placed in a grid inside the polygon
 * @returns {poly2tri.Triangle[]} Array of triangles partitioning the polygon
 */
export declare function triangulatePoly2tri(polygon: Ring, distance: number): poly2tri.Triangle[];
/**
 * Triangulates a polygon
 *
 * @remark Polygons with < 3 points just return an empty array.
 *
 * @param {Ring} polygon - Polygon
 * @param {number} distance - Distance between the Steiner points placed in a grid inside the polygon
 * @returns {Triangle[]} Array of triangles partitioning the polygon
 */
export declare function triangulate(polygon: Ring, distance: number): Triangle[];
/**
 * Triangulates a polygon and return unique points.
 * Grid points typically occure in 6 triangles
 * This function reutrns the list of unique points, and returns the triangles as uniquePointsIndexTriangles with indices refering to the unique points
 *
 * @remark Polygons with < 3 points just return an empty array.
 *
 * @param {Ring} polygon - Polygon
 * @param {number} distance - Distance between the Steiner points placed in a grid inside the polygon
 * @returns {{uniquePointsIndexTriangles: UniquePointsIndexTriangle[], uniquePoints: Point[]}} Object with uniquePointsIndexTriangles and uniquePoints
 */
export declare function triangulateToUnique(polygon: Ring, distance: number): {
    uniquePointsIndexTriangles: UniquePointsIndexTriangle[];
    uniquePoints: Point[];
};
